@@ -1,4 +1,5 @@
 from arkitekt.apps.connected import ConnectedApp
+from arkitekt.apps.fakts import ArkitektFakts
 from arkitekt.apps.rekuest import ArkitektRekuest
 from fakts.discovery.qt.selectable_beacon import (
     QtSelectableDiscovery,
@@ -7,6 +8,7 @@ from fakts.discovery.qt.selectable_beacon import (
 from fakts.fakts import Fakts
 from fakts.grants.meta.failsafe import FailsafeGrant
 from fakts.grants.remote.public_redirect_grant import PublicRedirectGrant
+from fakts.grants.remote.claim import ClaimGrant
 from herre.fakts.herre import FaktsHerre
 from koil.composition.qt import QtPedanticKoil
 from mikro_napari.widgets.main_widget import MikroNapariWidget
@@ -16,17 +18,25 @@ import argparse
 from skimage.data import astronaut
 
 from mikro_napari.widgets.sidebar.sidebar import SidebarWidget
-
+import os
 
 def main(**kwargs):
+
+    os.environ["NAPARI_ASYNC"] = "1"
+
     viewer = napari.Viewer()
 
     app = ConnectedApp(
         rekuest=ArkitektRekuest(),
-        fakts=Fakts(
+        fakts=ArkitektFakts(
             subapp="napari",
             grant=FailsafeGrant(
                 grants=[
+                    ClaimGrant(
+                        client_id="go8CAE78FDf4eLsOSk4wkR4usYbsamcq0yTYqBiY",
+                        client_secret="oO4eJgvv41Nkr9EaNAmZ5YI4WGgfJznUMW5ReGIcI6NsSXZiud3w3y2yGxdMf2WhEMdUKD6MMalLv1rlM8d6h5Q6vJR9vLbaKSHj2V5RpDrNVUWnJ1s2OmxiPSR6qoNH",
+                        discovery=QtSelectableDiscovery(widget=SelectBeaconWidget(parent=viewer.window.qt_viewer)),
+                    ),
                     PublicRedirectGrant(
                         name="Napari",
                         scopes=["openid"],
@@ -36,7 +46,7 @@ def main(**kwargs):
                     ),
                 ]
             ),
-            assert_groups={"mikro", "arkitekt"},
+            assert_groups={"mikro", "rekuest"},
         ),
         herre=FaktsHerre(),
     )
